qcacmn: wmi: Fix misspelling of 'accommodate'

Address the following issue in the wmi folder:
CHECK: 'accomodate' may be misspelled - perhaps 'accommodate'?

Change-Id: I7cdae0d5f5e9f17de9c3e4810edf9b87704a4f0a
CRs-Fixed: 2241588
diff --git a/wmi_tlv_helper.c b/wmi_tlv_helper.c
index 492ef6f..aa8f3a8 100644
--- a/wmi_tlv_helper.c
+++ b/wmi_tlv_helper.c
@@ -62,28 +62,28 @@
 /**
  * wmitlv_set_static_param_tlv_buf() - tlv helper function
  * @param_tlv_buf: tlv buffer parameter
  * @max_tlvs_accomodated: max no of tlv entries
  *
  *
  * WMI TLV Helper function to set the static cmd_param_tlv structure
  * and number of TLVs that can be accomodated in the structure.
  * This function should be used when dynamic memory allocation is not
  * supported. When dynamic memory allocation is not supported by any
  * component then NO_DYNAMIC_MEMALLOC macro has to be defined in respective
  * tlv_platform.c file. And respective component has to allocate
  * cmd_param_tlv structure buffer to accomodate whatever number of TLV's.
  * Both the buffer address and number of TLV's that can be accomodated in
  * the buffer should be sent as arguments to this function.
  *
  * Return None
  */
 void
 wmitlv_set_static_param_tlv_buf(void *param_tlv_buf,
-				uint32_t max_tlvs_accomodated)
+				uint32_t max_tlvs_accommodated)
 {
 #ifdef NO_DYNAMIC_MEM_ALLOC
 	g_wmi_static_cmd_param_info_buf = param_tlv_buf;
-	g_wmi_static_max_cmd_param_tlvs = max_tlvs_accomodated;
+	g_wmi_static_max_cmd_param_tlvs = max_tlvs_accommodated;
 #endif
 }
 
@@ -533,9 +533,9 @@
 	 * for base structure of format wmi_cmd_event_id##_param_tlvs */
 	*wmi_cmd_struct_ptr = g_wmi_static_cmd_param_info_buf;
 	if (attr_struct_ptr.cmd_num_tlv > g_wmi_static_max_cmd_param_tlvs) {
 		/* Error: Expecting more TLVs that accomodated for static structure  */
 		wmi_tlv_print_error
-			("%s: Error: Expecting more TLVs that accomodated for static structure. Expected:%d Accomodated:%d\n",
+			("%s: Error: Expecting more TLVs that accommodated for static structure. Expected:%d Accomodated:%d\n",
 			__func__, attr_struct_ptr.cmd_num_tlv,
 			g_wmi_static_max_cmd_param_tlvs);
 		return error;
@@ -62,28 +62,28 @@
  * wmitlv_set_static_param_tlv_buf() - tlv helper function
  * @param_tlv_buf: tlv buffer parameter
- * @max_tlvs_accomodated: max no of tlv entries
+ * @max_tlvs_accommodated: max no of tlv entries
  *
  *
@@ -62,28 +62,28 @@
  *
  * WMI TLV Helper function to set the static cmd_param_tlv structure
- * and number of TLVs that can be accomodated in the structure.
+ * and number of TLVs that can be accommodated in the structure.
  * This function should be used when dynamic memory allocation is not
  * supported. When dynamic memory allocation is not supported by any
@@ -62,28 +62,28 @@
  * component then NO_DYNAMIC_MEMALLOC macro has to be defined in respective
  * tlv_platform.c file. And respective component has to allocate
- * cmd_param_tlv structure buffer to accomodate whatever number of TLV's.
- * Both the buffer address and number of TLV's that can be accomodated in
+ * cmd_param_tlv structure buffer to accommodate whatever number of TLV's.
+ * Both the buffer address and number of TLV's that can be accommodated in
  * the buffer should be sent as arguments to this function.
  *
@@ -533,9 +533,9 @@
 	*wmi_cmd_struct_ptr = g_wmi_static_cmd_param_info_buf;
 	if (attr_struct_ptr.cmd_num_tlv > g_wmi_static_max_cmd_param_tlvs) {
-		/* Error: Expecting more TLVs that accomodated for static structure  */
+		/* Error: Expecting more TLVs that accommodated for static structure  */
 		wmi_tlv_print_error